==> SemSim_1.2.0.tar.gz: SemSim/man/mtermSim.Rd <==
\name{mtermSim}
\alias{mtermSim}
\title{Semantic Similarity Between Two Sets of GO Terms}
\description{
  Given multiple terms in each query set, semantic similarity is taken as the maximum, average, or row/column score combination of their pair-wise similarity values.
}
\usage{
mtermSim(GO1, GO2, ont, measure = "Resnik", db = "all", multiple = "max")
}
\arguments{
  \item{GO1}{First list of GO identifiers.}
  \item{GO2}{Second list of GO identifiers.}
  \item{ont}{One of "MF", "BP", and "CC" subontologies.}
  \item{measure}{One of "Resnik", "Lin", "Rel", and "Jiang" methods.}
  \item{db}{Databases from which the information content has been derived. See description in \code{\link{termSim}}.}
  \item{multiple}{Methods ("max", "avg", "rcmax") to combine pairwise similarity values between two lists of terms.}
}
\value{
  Semantic similarity or distance between two sets of terms.
}
\details{
  Gene products are often annotated by multiple terms. The maximum or average similarity between all terms associated with two gene products may be taken as the gene similarity. For Jiang's distance measure, minimum or average value will be taken as the combined distance. Alternatively, row score and column score may be calculated for the matrix of pairwise similarity values, and the maximum (minimum) of these two scores is used as the gene similarity (distance).   
}
\references{ 
  Schlicker, A., Domingues, F.S., Rahnenfuhrer, J., and Lengauer, T. (2006) A new measure for functional similarity of gene products based on Gene Ontology. \emph{BMC Bioinformatics}, 7(1):302.
}
\seealso{
  \code{\link{termSim}}
}
\examples{
  require(hgu133plus2)

  go1<-sapply(hgu133plus2GO[["203140_at"]], function(x) x$GOID)  
  go2<-sapply(hgu133plus2GO[["208368_s_at"]], function(x) x$GOID)

  mtermSim(go1, go2, ont="CC")
  mtermSim(go1, go2, ont="BP")
}
\keyword{manip}

==> SemSim_1.6.0.tar.gz: SemSim/man/mtermSim.Rd <==
\name{mtermSim}
\alias{mtermSim}
\title{Semantic Similarity Between Two Sets of GO Terms}
\description{
  Given multiple terms in each query set, semantic similarity is taken as the maximum, average, or row/column score combination of their pair-wise similarity values.
}
\usage{
mtermSim(GO1, GO2, ont, measure = "Resnik", db = "UniProt", multiple = "max")
}
\arguments{
  \item{GO1}{First list of GO identifiers.}
  \item{GO2}{Second list of GO identifiers.}
  \item{ont}{One of "MF", "BP", and "CC" subontologies.}
  \item{measure}{One of "Resnik", "Lin", "Rel", and "Jiang" methods.}
  \item{db}{Databases from which the information content has been derived. See description in \code{\link{termSim}}.}
  \item{multiple}{Methods ("max", "avg", "rcmax") to combine pairwise similarity values between two lists of terms.}
}
\value{
  Semantic similarity or distance between two sets of terms.
}
\details{
  Gene products are often annotated by multiple terms. The maximum or average similarity between all terms associated with two gene products may be taken as the gene similarity. For Jiang's distance measure, minimum or average value will be taken as the combined distance. Alternatively, row score and column score may be calculated for the matrix of pairwise similarity values, and the maximum (minimum) of these two scores is used as the gene similarity (distance).   
}
\references{ 
  Schlicker, A., Domingues, F.S., Rahnenfuhrer, J., and Lengauer, T. (2006) A new measure for functional similarity of gene products based on Gene Ontology. \emph{BMC Bioinformatics}, 7(1):302.
}
\seealso{
  \code{\link{termSim}}
}
\examples{
  require(hgu133plus2)

  go1<-sapply(hgu133plus2GO[["203140_at"]], function(x) x$GOID)  
  go2<-sapply(hgu133plus2GO[["208368_s_at"]], function(x) x$GOID)

  mtermSim(go1, go2, ont="CC")
  mtermSim(go1, go2, ont="BP")
}
\keyword{manip}
